[![Build Status](https://dev.azure.com/andreasisnes/Elitekollektivet/_apis/build/status/Elitekollektivet.Minesweeper/Elitekollektivet.Minesweeper.Core?branchName=master)](https://dev.azure.com/andreasisnes/Elitekollektivet/_build/latest?definitionId=13&branchName=master)
![PyPI - License](https://img.shields.io/pypi/l/pygame-minesweeper-core)
![PyPI](https://img.shields.io/pypi/v/pygame-minesweeper-core)
![Azure DevOps coverage](https://img.shields.io/azure-devops/coverage/andreasisnes/Elitekollektivet/13)

# Introduction
